@@ -52,8 +52,8 @@ def convert_choices_if_needed(  # noqa: CCR001
 
     :param field: ormar field to check with choices
     :type field: BaseField
-    :param values: current values of the model to verify
-    :type values: Dict
+    :param value: current values of the model to verify
+    :type value: Dict
     :return: value, choices list
     :rtype: Tuple[Any, List]
     """
@@ -97,6 +97,8 @@ def validate_choices(field: "BaseField", value: Any) -> None:
     :type value: Any
     """
     value, choices = convert_choices_if_needed(field=field, value=value)
+    if field.nullable:
+        choices.append(None)
     if value is not ormar.Undefined and value not in choices:
         raise ValueError(
             f"{field.name}: '{value}' " f"not in allowed choices set:" f" {choices}"
@@ -232,10 +234,9 @@ def get_pydantic_example_repr(type_: Any) -> Any:
     """
     if issubclass(type_, (numbers.Number, decimal.Decimal)):
         return 0
-    elif issubclass(type_, pydantic.BaseModel):
+    if issubclass(type_, pydantic.BaseModel):
         return generate_pydantic_example(pydantic_model=type_)
-    else:
-        return "string"
+    return "string"
 
 
 def overwrite_example_and_description(
